Build 2044
SVN-
in 3 planes -> packed format conversion code, group together the
Mostra dettagli
three individual loops and compile the enclosing function at -O3 (-O1 for debugging builds). Now, the time for this conversion ranges from 7 to 18 ms per frame across various tested machines, a clear improvement.